[Zope3-checkins] CVS: Zope3/src/zope/app/browser/services/tests - test_bundle.py:1.2 test_service.py:1.4

Jim Fulton jim@zope.com
Sat, 21 Jun 2003 17:22:38 -0400


Update of /cvs-repository/Zope3/src/zope/app/browser/services/tests
In directory cvs.zope.org:/tmp/cvs-serv2745/src/zope/app/browser/services/tests

Modified Files:
	test_bundle.py test_service.py 
Log Message:
Major refactoring to reflect change in terminology from
"configuration" to "registration" to refer to the configuration of how
objects are used (as opposed to their internal configuration).


=== Zope3/src/zope/app/browser/services/tests/test_bundle.py 1.1 => 1.2 ===
--- Zope3/src/zope/app/browser/services/tests/test_bundle.py:1.1	Thu Jun 19 17:33:01 2003
+++ Zope3/src/zope/app/browser/services/tests/test_bundle.py	Sat Jun 21 17:22:04 2003
@@ -78,9 +78,9 @@
         infos = bv.listServices()
         self.assertEquals(infos, [])
 
-    def test_listConfigurations(self):
+    def test_listRegistrations(self):
         bv = BundleView(SampleClass("/++etc++site/foo-bar-1.0.0"), None)
-        infos = bv.listConfigurations()
+        infos = bv.listRegistrations()
         self.assertEquals(infos, [])
 
 


=== Zope3/src/zope/app/browser/services/tests/test_service.py 1.3 => 1.4 ===
--- Zope3/src/zope/app/browser/services/tests/test_service.py:1.3	Fri Jun  6 16:44:29 2003
+++ Zope3/src/zope/app/browser/services/tests/test_service.py	Sat Jun 21 17:22:04 2003
@@ -11,7 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Unit tests for service adding and configuration views.
 
 $Id$
 """
@@ -43,7 +43,7 @@
                 return self.context.url
             __call__ = __str__
         provideView(IFoo, 'absolute_url', IBrowserPresentation, AU)
-        provideView(IFoo, 'addConfiguration.html', IBrowserPresentation, AU)
+        provideView(IFoo, 'addRegistration.html', IBrowserPresentation, AU)
 
         context = Foo('foo_url')
         request = TestRequest()
@@ -52,7 +52,7 @@
         self.assertEquals(view.nextURL(), 'foo_url/@@contents.html')
 
         view.added_object = Foo('bar_url')
-        self.assertEquals(view.nextURL(), 'bar_url/@@addConfiguration.html')
+        self.assertEquals(view.nextURL(), 'bar_url/@@addRegistration.html')
 
 
 # XXX: add tests for other methods and classes
@@ -11,7 +11,7 @@
 #
 ##############################################################################
-"""Unit tests for service adding and configuration views.
+"""Unit tests for service adding and registration views.
 
 $Id$